{% import 'elementor/macros' as m %}
{%- set classes = settings.classes | merge([base_styles.base]) | join(' ') -%}
{%- if settings.link is defined and settings.link.href is defined and settings.link.href is not empty -%}
	<{{ settings.link.tag | default('a') | e('html_tag') }}{{ m.render_link_attributes(settings.link) }} class="{{ classes }}" data-interaction-id="{{ interaction_id }}"
		{{- m.render_custom_attributes(settings) }}>{{ settings.svg.html | raw }}</{{ settings.link.tag | default('a') | e('html_tag') }}>
{%- else -%}
	<div class="{{ classes }}" data-interaction-id="{{ interaction_id }}"
		{{- m.render_custom_attributes(settings) }}>{{ settings.svg.html | raw }}</div>
{%- endif -%}
